@@ -7,7 +7,7 @@ import { searchClient } from '../../../search-sdk/search-client'
 import { useSavedSearchesQuery, useSearchResultCountQuery, UserSearch } from '../../../search-sdk/search-sdk'
 import { convertStringToQuery } from '../search-helper'
 import SuggestQueryTemplates from './SuggestedQueryTemplates'
-import { AcmAlert, AcmExpandableWrapper, AcmCountCard } from '@stolostron/ui-components'
+import { AcmAlert, AcmExpandableWrapper, AcmCountCard } from '@open-cluster-management/ui-components'
 import { updateBrowserUrl } from '../urlQuery'
 import { SaveAndEditSearchModal } from './Modals/SaveAndEditSearchModal'
 import { DeleteSearchModal } from './Modals/DeleteSearchModal'
@@ -85,6 +85,7 @@ function SearchResultCount(
                     setSelectedSearch={setSelectedSearch}
                     editSearch={editSearch}
                     onClose={() => setEditSearch(undefined)}
+                    savedSearchQueries={queries}
                 />
                 <ShareSearchModal shareSearch={shareSearch} onClose={() => setShareSearch(undefined)} />
                 <DeleteSearchModal deleteSearch={deleteSearch} onClose={() => setDeleteSearch(undefined)} />
