@@ -33,8 +33,8 @@ const logSymbols = _interopDefault(require('log-symbols'));
 const ansiEscapes = _interopDefault(require('ansi-escapes'));
 const wrapAnsi = _interopDefault(require('wrap-ansi'));
 const commonTags = require('common-tags');
+const UpdateRenderer = _interopDefault(require('listr-update-renderer'));
 const graphql = require('graphql');
-const utils = require('@graphql-tools/utils');
 const cosmiconfig = require('cosmiconfig');
 const stringEnvInterpolation = require('string-env-interpolation');
 const yargs = _interopDefault(require('yargs'));
@@ -49,12 +49,14 @@ const graphqlFileLoader = require('@graphql-tools/graphql-file-loader');
 const jsonFileLoader = require('@graphql-tools/json-file-loader');
 const urlLoader = require('@graphql-tools/url-loader');
 const yaml = _interopDefault(require('yaml'));
+const module$1 = require('module');
 const fs = require('fs');
 const fs__default = _interopDefault(fs);
-const module$1 = require('module');
+const Listr = _interopDefault(require('listr'));
 const isGlob = _interopDefault(require('is-glob'));
 const debounce = _interopDefault(require('debounce'));
-const mkdirp = require('mkdirp');
+const utils = require('@graphql-tools/utils');
+const mkdirp = _interopDefault(require('mkdirp'));
 const crypto = require('crypto');
 const inquirer = _interopDefault(require('inquirer'));
 const detectIndent = _interopDefault(require('detect-indent'));
@@ -210,7 +212,6 @@ function indentString(string, count = 1, options = {}) {
     return string.replace(regex, indent.repeat(count));
 }
 
-const UpdateRenderer = require('listr-update-renderer');
 class Renderer {
     constructor(tasks, options) {
         this.updateRenderer = new UpdateRenderer(tasks, options);
@@ -351,10 +352,10 @@ async function getPluginByName(name, pluginLoader) {
             return await pluginLoader(moduleName);
         }
         catch (err) {
-            if (err.code !== 'MODULE_NOT_FOUND' || !err.message.includes(moduleName)) {
+            if (err.code !== 'MODULE_NOT_FOUND') {
                 throw new pluginHelpers.DetailedError(`Unable to load template plugin matching ${name}`, `
               Unable to load template plugin matching '${name}'.
-              Reason: 
+              Reason:
                 ${err.message}
             `);
             }
@@ -368,7 +369,7 @@ async function getPluginByName(name, pluginLoader) {
     throw new pluginHelpers.DetailedError(`Unable to find template plugin matching ${name}`, `
         Unable to find template plugin matching '${name}'
         Install one of the following packages:
-        
+
         ${possibleNamesMsg}
       `);
 }
@@ -387,10 +388,10 @@ async function getPresetByName(name, loader) {
             return loaded;
         }
         catch (err) {
-            if (err.code !== 'MODULE_NOT_FOUND' || !err.message.includes(moduleName)) {
+            if (err.code !== 'MODULE_NOT_FOUND') {
                 throw new pluginHelpers.DetailedError(`Unable to load preset matching ${name}`, `
               Unable to load preset matching '${name}'.
-              Reason: 
+              Reason:
                 ${err.message}
             `);
             }
@@ -404,20 +405,28 @@ async function getPresetByName(name, loader) {
     throw new pluginHelpers.DetailedError(`Unable to find preset matching ${name}`, `
         Unable to find preset matching '${name}'
         Install one of the following packages:
-        
+
         ${possibleNamesMsg}
       `);
 }
 
 const CodegenExtension = (api) => {
     // Schema
-    api.loaders.schema.register(new codeFileLoader.CodeFileLoader());
+    api.loaders.schema.register(new codeFileLoader.CodeFileLoader({
+        pluckConfig: {
+            skipIndent: true,
+        },
+    }));
     api.loaders.schema.register(new gitLoader.GitLoader());
     api.loaders.schema.register(new githubLoader.GithubLoader());
     api.loaders.schema.register(new apolloEngineLoader.ApolloEngineLoader());
     api.loaders.schema.register(new prismaLoader.PrismaLoader());
     // Documents
-    api.loaders.documents.register(new codeFileLoader.CodeFileLoader());
+    api.loaders.documents.register(new codeFileLoader.CodeFileLoader({
+        pluckConfig: {
+            skipIndent: true,
+        },
+    }));
     api.loaders.documents.register(new gitLoader.GitLoader());
     api.loaders.documents.register(new githubLoader.GithubLoader());
     return {
@@ -510,10 +519,27 @@ async function loadSchema(schemaPointers, config) {
     }
 }
 async function loadDocuments(documentPointers, config) {
-    const loaders = [new codeFileLoader.CodeFileLoader(), new gitLoader.GitLoader(), new githubLoader.GithubLoader(), new graphqlFileLoader.GraphQLFileLoader()];
+    const loaders = [
+        new codeFileLoader.CodeFileLoader({
+            pluckConfig: {
+                skipIndent: true,
+            },
+        }),
+        new gitLoader.GitLoader(),
+        new githubLoader.GithubLoader(),
+        new graphqlFileLoader.GraphQLFileLoader(),
+    ];
+    const ignore = [];
+    for (const generatePath of Object.keys(config.generates)) {
+        if (path.extname(generatePath) === '') {
+            // we omit paths that don't resolve to a specific file
+            continue;
+        }
+        ignore.push(path.join(process.cwd(), generatePath));
+    }
     const loadedFromToolkit = await load.loadDocuments(documentPointers, {
         ...defaultDocumentsLoadOptions,
-        ignore: Object.keys(config.generates).map(p => path.join(process.cwd(), p)),
+        ignore,
         loaders,
         ...config,
         ...config.config,
@@ -654,7 +680,10 @@ function parseArgv(argv = process.argv) {
 }
 async function createContext(cliFlags = parseArgv(process.argv)) {
     if (cliFlags.require && cliFlags.require.length > 0) {
-        await Promise.all(cliFlags.require.map(mod => new Promise(function (resolve) { resolve(_interopNamespace(require(require.resolve(mod, { paths: [process.cwd()] })))); })));
+        const relativeRequire = module$1.createRequire(process.cwd());
+        await Promise.all(cliFlags.require.map(mod => new Promise(function (resolve) { resolve(_interopNamespace(require(relativeRequire.resolve(mod, {
+            paths: [process.cwd()],
+        })))); })));
     }
     const customConfigPath = getCustomConfigPath(cliFlags);
     const context = await loadContext(customConfigPath);
@@ -748,7 +777,7 @@ const makeDefaultLoader = (from) => {
     if (fs__default.statSync(from).isDirectory()) {
         from = path__default.join(from, '__fake.js');
     }
-    const relativeRequire = (module$1.createRequire || module$1.createRequireFromPath)(from);
+    const relativeRequire = module$1.createRequire(from);
     return (mod) => {
         return new Promise(function (resolve) { resolve(_interopNamespace(require(relativeRequire.resolve(mod)))); });
     };
@@ -774,7 +803,6 @@ async function executeCodegen(input) {
     const commonListrOptions = {
         exitOnError: true,
     };
-    const Listr = await new Promise(function (resolve) { resolve(_interopNamespace(require('listr'))); }).then(m => ('default' in m ? m.default : m));
     let listr;
     if (process.env.VERBOSE) {
         listr = new Listr({
@@ -821,7 +849,7 @@ async function executeCodegen(input) {
         if (generateKeys.length === 0) {
             throw new pluginHelpers.DetailedError('Invalid Codegen Configuration!', `
         Please make sure that your codegen config file contains the "generates" field, with a specification for the plugins you need.
-        
+
         It should looks like that:
 
         schema:
@@ -834,13 +862,13 @@ async function executeCodegen(input) {
         `);
         }
         for (const filename of generateKeys) {
-            generates[filename] = pluginHelpers.normalizeOutputParam(config.generates[filename]);
-            if (generates[filename].plugins.length === 0) {
+            const output = (generates[filename] = pluginHelpers.normalizeOutputParam(config.generates[filename]));
+            if (!output.preset && (!output.plugins || output.plugins.length === 0)) {
                 throw new pluginHelpers.DetailedError('Invalid Codegen Configuration!', `
           Please make sure that your codegen config file has defined plugins list for output "${filename}".
-          
+
           It should looks like that:
-  
+
           schema:
             - my-schema.graphql
           generates:
@@ -854,9 +882,9 @@ async function executeCodegen(input) {
         if (rootSchemas.length === 0 &&
             Object.keys(generates).some(filename => !generates[filename].schema || generates[filename].schema.length === 0)) {
             throw new pluginHelpers.DetailedError('Invalid Codegen Configuration!', `
-        Please make sure that your codegen config file contains either the "schema" field 
+        Please make sure that your codegen config file contains either the "schema" field
         or every generated file has its own "schema" field.
-        
+
         It should looks like that:
         schema:
           - my-schema.graphql
@@ -905,7 +933,7 @@ async function executeCodegen(input) {
                                         }
                                     }
                                     outputSchemaAst = await context.loadSchema(schemaPointerMap);
-                                    outputSchema = graphql.parse(utils.printSchemaWithDirectives(outputSchemaAst));
+                                    outputSchema = pluginHelpers.getCachedDocumentNodeFromSchema(outputSchemaAst);
                                 }, filename),
                             },
                             {
@@ -1092,7 +1120,11 @@ const createWatcher = (initalContext, onNext) => {
             lifecycleHooks(config.hooks).onWatchTriggered(eventName, path$1);
             debugLog(`[Watcher] triggered due to a file ${eventName} event: ${path$1}`);
             const fullPath = path.join(process.cwd(), path$1);
-            delete require.cache[fullPath];
+            // In ESM require is not defined
+            try {
+                delete require.cache[fullPath];
+            }
+            catch (err) { }
             if (eventName === 'change' && config.configFilePath && fullPath === config.configFilePath) {
                 log(`${logSymbols.info} Config file has changed, reloading...`);
                 const context = await loadContext(config.configFilePath);
@@ -1359,7 +1391,7 @@ const plugins = [
         defaultExtension: '.js',
     },
     {
-        name: `TypeScript Vue Apollo ${italic('(typed composition functions)')}`,
+        name: `TypeScript Vue Apollo Composition API ${italic('(typed functions)')}`,
         package: '@graphql-codegen/typescript-vue-apollo',
         value: 'typescript-vue-apollo',
         pathInRepo: 'typescript/vue-apollo',
@@ -1367,6 +1399,15 @@ const plugins = [
         shouldBeSelected: () => true,
         defaultExtension: '.ts',
     },
+    {
+        name: `TypeScript Vue Apollo Smart Operations ${italic('(typed functions)')}`,
+        package: '@graphql-codegen/typescript-vue-apollo-smart-ops',
+        value: 'typescript-vue-apollo-smart-ops',
+        pathInRepo: 'typescript/vue-apollo-smart-ops',
+        available: tags => allOf(tags, Tags.vue, Tags.typescript),
+        shouldBeSelected: () => true,
+        defaultExtension: '.ts',
+    },
     {
         name: `TypeScript React Apollo ${italic('(typed components and HOCs)')}`,
         package: '@graphql-codegen/typescript-react-apollo',
@@ -1673,8 +1714,8 @@ function addIntrospection(config) {
     };
 }
 
-function runCli(cmd) {
-    ensureGraphQlPackage();
+async function runCli(cmd) {
+    await ensureGraphQlPackage();
     switch (cmd) {
         case 'init':
             return init();
@@ -1688,9 +1729,9 @@ function runCli(cmd) {
         }
     }
 }
-function ensureGraphQlPackage() {
+async function ensureGraphQlPackage() {
     try {
-        require('graphql');
+        await new Promise(function (resolve) { resolve(_interopNamespace(require('graphql'))); });
     }
     catch (e) {
         throw new pluginHelpers.DetailedError(`Unable to load "graphql" package. Please make sure to install "graphql" as a dependency!`, `
