@@ -1,6 +1,6 @@
 /*!-----------------------------------------------------------
  * Copyright (c) Microsoft Corporation. All rights reserved.
- * Version: 0.25.1(336c463ee6c20d8a49e40d099b9178def0df6b18)
+ * Version: 0.26.0(69d9363bfed1fbfc1ccb914875a20299f46bcc2e)
  * Released under the MIT license
  * https://github.com/microsoft/vscode/blob/main/LICENSE.txt
  *-----------------------------------------------------------*/
@@ -213,7 +213,7 @@ define("vs/editor/editor.main.nls.it", {
 		"Abilita i suggerimenti incorporati nell\'Editor.",
 		"Controlla le dimensioni del carattere dei suggerimenti incorporati nell\'Editor. Quando è impostato su `0`, viene usato il 90% del valore di `#editor.fontSize#`.",
 		"Controlla la famiglia di caratteri dei suggerimenti incorporati nell\'Editor.",
-		"Controlla l\'altezza della riga. Usare 0 per calcolare l\'altezza della riga dalle dimensioni del carattere.",
+		"Controlla l\'altezza della riga. \r\n - Usare 0 per calcolare automaticamente l\'altezza della riga dalle dimensioni del carattere.\r\n - I valori compresi tra 0 e 8 verranno usati come moltiplicatore con le dimensioni del carattere.\r\n - I valori maggiori o uguali a 8 verranno usati come valori effettivi.",
 		"Controlla se la minimappa è visualizzata.",
 		"La minimappa ha le stesse dimensioni del contenuto dell\'editor (e potrebbe supportare lo scorrimento).",
 		"Se necessario, la minimappa si ridurrà o si ingrandirà in modo da adattarsi all\'altezza dell\'editor (nessuno scorrimento).",
@@ -240,7 +240,21 @@ define("vs/editor/editor.main.nls.it", {
 		"Numero di caratteri a spaziatura fissa in corrispondenza del quale verrà eseguito il rendering di questo righello dell\'editor.",
 		"Colore di questo righello dell\'editor.",
 		"Esegue il rendering dei righelli verticali dopo un certo numero di caratteri a spaziatura fissa. Usare più valori per più righelli. Se la matrice è vuota, non viene disegnato alcun righello.",
+		"La barra di scorrimento verticale sarà visibile solo quando necessario.",
+		"La barra di scorrimento verticale sarà sempre visibile.",
+		"La barra di scorrimento verticale sarà sempre nascosta.",
+		"Controlla la visibilità della barra di scorrimento verticale.",
+		"La barra di scorrimento orizzontale sarà visibile solo quando necessario.",
+		"La barra di scorrimento orizzontale sarà sempre visibile.",
+		"La barra di scorrimento orizzontale sarà sempre nascosta.",
+		"Controlla la visibilità della barra di scorrimento orizzontale.",
+		"Larghezza della barra di scorrimento verticale.",
+		"Altezza della barra di scorrimento orizzontale.",
+		"Controlla se i clic consentono di attivare lo scorrimento per pagina o di passare direttamente alla posizione di clic.",
 		"Controlla se visualizzare automaticamente i suggerimenti inline nell\'Editor.",
+		"Eseguire il rendering di un suggerimento inline solo se il testo di sostituzione è un prefisso del testo di inserimento.",
+		"Eseguire il rendering di un suggerimento inline solo se il testo di sostituzione è una parola secondaria del testo di inserimento.",
+		"Verificare la modalità da utilizzare per eseguire il rendering dei suggerimenti inline.",
 		"Inserisce il suggerimento senza sovrascrivere il testo a destra del cursore.",
 		"Inserisce il suggerimento e sovrascrive il testo a destra del cursore.",
 		"Controlla se le parole vengono sovrascritte quando si accettano i completamenti. Tenere presente che questa opzione dipende dalle estensioni che accettano esplicitamente questa funzionalità.",
@@ -251,6 +265,9 @@ define("vs/editor/editor.main.nls.it", {
 		"Controlla se mostrare o nascondere le icone nei suggerimenti.",
 		"Controlla la visibilità della barra di stato nella parte inferiore del widget dei suggerimenti.",
 		"Controlla se visualizzare in anteprima il risultato del suggerimento nell\'Editor.",
+		"Eseguire il rendering di un’anteprima solo se il testo di sostituzione è un prefisso del testo di inserimento.",
+		"Eseguire il rendering di un’anteprima solo se il testo di sostituzione è una parola secondaria del testo di inserimento.",
+		"Verificare la modalità da utilizzare per eseguire il rendering dell\'anteprima del suggerimento.",
 		"Controlla se i dettagli del suggerimento vengono visualizzati inline con l\'etichetta o solo nel widget dei dettagli",
 		"Questa impostazione è deprecata. Il widget dei suggerimenti può ora essere ridimensionato.",
 		"Questa impostazione è deprecata. In alternativa, usare impostazioni diverse, come \'editor.suggest.showKeywords\' o \'editor.suggest.showSnippets\'.",
@@ -795,6 +812,7 @@ define("vs/editor/editor.main.nls.it", {
 	],
 	"vs/editor/contrib/hover/markdownHoverParticipant": [
 		"Caricamento...",
+		"Per motivi di prestazioni la tokenizzazione viene ignorata per le righe lunghe. È possibile effettuare questa configurazione tramite `editor.maxTokenizationLineLength`.",
 	],
 	"vs/editor/contrib/hover/markerHoverParticipant": [
 		"Visualizza problema",
@@ -1061,6 +1079,7 @@ define("vs/editor/editor.main.nls.it", {
 		"Colore del bordo del widget dei suggerimenti.",
 		"Colore primo piano del widget dei suggerimenti.",
 		"Colore primo piano della voce selezionata del widget dei suggerimenti.",
+		"Colore primo piano dell’icona della voce selezionata del widget dei suggerimenti.",
 		"Colore di sfondo della voce selezionata del widget dei suggerimenti.",
 		"Colore delle evidenziazioni corrispondenze nel widget dei suggerimenti.",
 		"Colore delle evidenziazioni corrispondenze nel widget dei suggerimenti quando lo stato attivo si trova su un elemento.",
@@ -1126,9 +1145,9 @@ define("vs/editor/editor.main.nls.it", {
 	"vs/editor/contrib/unusualLineTerminators/unusualLineTerminators": [
 		"Caratteri di terminazione di riga insoliti",
 		"Sono stati rilevati caratteri di terminazione di riga insoliti",
-		"Questo file contiene uno o più caratteri di terminazione di riga insoliti, ad esempio separatore di riga (LS) o separatore di paragrafo (PS).\r\n\r\nÈ consigliabile rimuoverli dal file. È possibile configurare questa opzione tramite `editor.unusualLineTerminators`.",
-		"Correggi questo file",
-		"Ignora il problema per questo file",
+		"Il file \"\r\n\" contiene uno o più caratteri di terminazione di riga insoliti, ad esempio separatore di riga (LS) o separatore di paragrafo (PS).{0}\r\nÈ consigliabile rimuoverli dal file. È possibile configurare questa opzione tramite `editor.unusualLineTerminators`.",
+		"Rimuovi i caratteri di terminazione di riga insoliti",
+		"Ignora",
 	],
 	"vs/editor/contrib/wordHighlighter/wordHighlighter": [
 		"Colore di sfondo di un simbolo durante l\'accesso in lettura, ad esempio durante la lettura di una variabile. Il colore non deve essere opaco per evitare di nascondere le decorazioni sottostanti.",
@@ -1193,7 +1212,6 @@ define("vs/editor/editor.main.nls.it", {
 		"usate di recente",
 		"altri comandi",
 		"Il comando \'{0}\' ha restituito un errore ({1})",
-		"OK",
 	],
 	"vs/platform/quickinput/browser/helpQuickAccess": [
 		"comandi globali",
@@ -1208,6 +1226,7 @@ define("vs/editor/editor.main.nls.it", {
 		"Un bordo supplementare attorno agli elementi per contrastarli maggiormente rispetto agli altri.",
 		"Un bordo supplementare intorno agli elementi attivi per contrastarli maggiormente rispetto agli altri.",
 		"Colore primo piano dei link nel testo.",
+		"Colore primo piano per i collegamenti nel testo quando vengono selezionati o al passaggio del mouse.",
 		"Colore di sfondo per i blocchi di codice nel testo.",
 		"Colore ombreggiatura dei widget, ad es. Trova/Sostituisci all\'interno dell\'editor.",
 		"Sfondo della casella di input.",
@@ -1295,8 +1314,10 @@ define("vs/editor/editor.main.nls.it", {
 		"Colore del contorno dell\'elenco/albero per l\'elemento con lo stato attivo quando l\'elenco/albero è attivo. Un elenco/albero attivo ha lo stato attivo della tastiera, a differenza di uno inattivo.",
 		"Colore di sfondo dell\'elenco/albero per l\'elemento selezionato quando l\'elenco/albero è attivo. Un elenco/albero attivo ha lo stato attivo della tastiera, a differenza di uno inattivo.",
 		"Colore primo piano dell\'elenco/albero per l\'elemento selezionato quando l\'elenco/albero è attivo. Un elenco/albero attivo ha lo stato attivo della tastiera, a differenza di uno inattivo.",
+		"Colore primo piano dell’icona dell\'elenco/albero per l\'elemento selezionato quando l\'elenco/albero è attivo. Un elenco/albero attivo ha lo stato attivo della tastiera, a differenza di uno inattivo.",
 		"Colore di sfondo dell\'elenco/albero per l\'elemento selezionato quando l\'elenco/albero è inattivo. Un elenco/albero attivo ha lo stato attivo della tastiera, a differenza di uno inattivo.",
 		"Colore primo piano dell\'elenco/albero per l\'elemento selezionato quando l\'elenco/albero è inattivo. Un elenco/albero attivo ha lo stato attivo della tastiera, a differenza di uno inattivo.",
+		"Colore primo piano dell’icona dell\'elenco/albero per l\'elemento selezionato quando l\'elenco/albero è inattivo. Un elenco/albero attivo ha lo stato attivo della tastiera, a differenza di uno inattivo.",
 		"Colore di sfondo dell\'elenco/albero per l\'elemento con lo stato attivo quando l\'elenco/albero è inattivo. Un elenco/albero attivo ha lo stato attivo della tastiera, uno inattivo no.",
 		"Colore del contorno dell\'elenco/albero per l\'elemento con lo stato attivo quando l\'elenco/albero è inattivo. Un elenco/albero attivo ha lo stato attivo della tastiera, a differenza di uno inattivo.",
 		"Sfondo dell\'elenco/albero al passaggio del mouse sugli elementi.",
@@ -1311,6 +1332,7 @@ define("vs/editor/editor.main.nls.it", {
 		"Colore del tratto dell\'albero per le guide per i rientri.",
 		"In alternativa, usare quickInputList.focusBackground",
 		"Colore primo piano di Selezione rapida per l\'elemento con lo stato attivo.",
+		"Colore primo piano dell’icona di Selezione rapida per l\'elemento con lo stato attivo.",
 		"Colore di sfondo di Selezione rapida per l\'elemento con lo stato attivo.",
 		"Colore del bordo del menu.",
 		"Colore primo piano delle voci di menu.",
@@ -1356,7 +1378,7 @@ define("vs/editor/editor.main.nls.it", {
 		"Annulla",
 		"Non è stato possibile annullare \'{0}\' perché è già in esecuzione un\'operazione di annullamento o ripetizione.",
 		"Annullare \'{0}\'?",
-		"Annulla",
+		"Sì",
 		"Annulla",
 		"Non è stato possibile ripetere \'{0}\' in tutti i file. {1}",
 		"Non è stato possibile ripetere \'{0}\' in tutti i file. {1}",
