@@ -14,6 +14,7 @@ const autoCloseNever = () => false;
 const autoCloseBeforeWhitespace = (chr) => (chr === ' ' || chr === '\t');
 export class CursorConfiguration {
     constructor(languageIdentifier, modelOptions, configuration) {
+        this._cursorMoveConfigurationBrand = undefined;
         this._languageIdentifier = languageIdentifier;
         const options = configuration.options;
         const layoutInfo = options.get(128 /* layoutInfo */);
@@ -126,6 +127,7 @@ export class CursorConfiguration {
  */
 export class SingleCursorState {
     constructor(selectionStart, selectionStartLeftoverVisibleColumns, position, leftoverVisibleColumns) {
+        this._singleCursorStateBrand = undefined;
         this.selectionStart = selectionStart;
         this.selectionStartLeftoverVisibleColumns = selectionStartLeftoverVisibleColumns;
         this.position = position;
@@ -178,6 +180,7 @@ export class SingleCursorState {
 }
 export class CursorContext {
     constructor(model, coordinatesConverter, cursorConfig) {
+        this._cursorContextBrand = undefined;
         this.model = model;
         this.coordinatesConverter = coordinatesConverter;
         this.cursorConfig = cursorConfig;
@@ -197,6 +200,7 @@ export class PartialViewCursorState {
 }
 export class CursorState {
     constructor(modelState, viewState) {
+        this._cursorStateBrand = undefined;
         this.modelState = modelState;
         this.viewState = viewState;
     }
@@ -227,6 +231,7 @@ export class CursorState {
 }
 export class EditOperationResult {
     constructor(type, commands, opts) {
+        this._editOperationResultBrand = undefined;
         this.type = type;
         this.commands = commands;
         this.shouldPushStackElementBefore = opts.shouldPushStackElementBefore;
