@@ -186,6 +186,9 @@ function toTextEdit(textEdit) {
         text: textEdit.newText
     };
 }
+function toCommand(c) {
+    return c && c.command === 'editor.action.triggerSuggest' ? { id: c.command, title: c.title, arguments: c.arguments } : undefined;
+}
 var CompletionAdapter = /** @class */ (function () {
     function CompletionAdapter(_worker) {
         this._worker = _worker;
@@ -217,6 +220,7 @@ var CompletionAdapter = /** @class */ (function () {
                     filterText: entry.filterText,
                     documentation: entry.documentation,
                     detail: entry.detail,
+                    command: toCommand(entry.command),
                     range: wordRange,
                     kind: toCompletionItemKind(entry.kind)
                 };
