@@ -724,6 +724,8 @@ module.exports = (issuer, aadIssValidation = false) => class Client extends Base
       });
     }
 
+    const fapi = this.constructor.name === 'FAPIClient';
+
     if (returnedBy === 'authorization') {
       if (!payload.at_hash && tokenSet.access_token) {
         throw new RPError({
@@ -739,19 +741,7 @@ module.exports = (issuer, aadIssValidation = false) => class Client extends Base
         });
       }
 
-      const fapi = this.constructor.name === 'FAPIClient';
-
       if (fapi) {
-        if (payload.iat < timestamp - 3600) {
-          throw new RPError({
-            printf: ['JWT issued too far in the past, now %i, iat %i', timestamp, payload.iat],
-            now: timestamp,
-            tolerance: this[CLOCK_TOLERANCE],
-            iat: payload.iat,
-            jwt: idToken,
-          });
-        }
-
         if (!payload.s_hash && (tokenSet.state || state)) {
           throw new RPError({
             message: 'missing required property s_hash',
@@ -773,6 +763,16 @@ module.exports = (issuer, aadIssValidation = false) => class Client extends Base
       }
     }
 
+    if (fapi && payload.iat < timestamp - 3600) {
+      throw new RPError({
+        printf: ['JWT issued too far in the past, now %i, iat %i', timestamp, payload.iat],
+        now: timestamp,
+        tolerance: this[CLOCK_TOLERANCE],
+        iat: payload.iat,
+        jwt: idToken,
+      });
+    }
+
     if (tokenSet.access_token && payload.at_hash !== undefined) {
       try {
         tokenHash.validate({ claim: 'at_hash', source: 'access_token' }, payload.at_hash, tokenSet.access_token, header.alg, key && key.crv);
@@ -1013,8 +1013,9 @@ module.exports = (issuer, aadIssValidation = false) => class Client extends Base
       method,
       headers,
       body,
-      tokenType = accessToken instanceof TokenSet ? accessToken.token_type : 'Bearer',
       DPoP,
+      // eslint-disable-next-line no-nested-ternary
+      tokenType = DPoP ? 'DPoP' : accessToken instanceof TokenSet ? accessToken.token_type : 'Bearer',
     } = {},
   ) {
     if (accessToken instanceof TokenSet) {
@@ -1039,7 +1040,7 @@ module.exports = (issuer, aadIssValidation = false) => class Client extends Base
       responseType: 'buffer',
       method,
       url: resourceUrl,
-    }, { mTLS, DPoP });
+    }, { accessToken, mTLS, DPoP });
   }
 
   /**
@@ -1487,14 +1488,17 @@ module.exports = (issuer, aadIssValidation = false) => class Client extends Base
     let signed;
     let key;
 
+    const fapi = this.constructor.name === 'FAPIClient';
+    const unix = now();
     const header = { alg: signingAlgorithm, typ: 'oauth-authz-req+jwt' };
     const payload = JSON.stringify(defaults({}, requestObject, {
       iss: this.client_id,
       aud: this.issuer.issuer,
       client_id: this.client_id,
       jti: random(),
-      iat: now(),
-      exp: now() + 300,
+      iat: unix,
+      exp: unix + 300,
+      ...(fapi ? { nbf: unix } : undefined),
     }));
 
     if (signingAlgorithm === 'none') {
@@ -1547,6 +1551,57 @@ module.exports = (issuer, aadIssValidation = false) => class Client extends Base
     });
   }
 
+  /**
+   * @name pushedAuthorizationRequest
+   * @api public
+   */
+  async pushedAuthorizationRequest(params = {}, { clientAssertionPayload } = {}) {
+    assertIssuerConfiguration(this.issuer, 'pushed_authorization_request_endpoint');
+
+    const body = {
+      ...('request' in params ? params : authorizationParams.call(this, params)),
+      client_id: this.client_id,
+    };
+
+    const response = await authenticatedPost.call(
+      this,
+      'pushed_authorization_request',
+      {
+        responseType: 'json',
+        form: body,
+      },
+      { clientAssertionPayload, endpointAuthMethod: 'token' },
+    );
+    const responseBody = processResponse(response, { statusCode: 201 });
+
+    if (!('expires_in' in responseBody)) {
+      throw new RPError({
+        message: 'expected expires_in in Pushed Authorization Successful Response',
+        response,
+      });
+    }
+    if (typeof responseBody.expires_in !== 'number') {
+      throw new RPError({
+        message: 'invalid expires_in value in Pushed Authorization Successful Response',
+        response,
+      });
+    }
+    if (!('request_uri' in responseBody)) {
+      throw new RPError({
+        message: 'expected request_uri in Pushed Authorization Successful Response',
+        response,
+      });
+    }
+    if (typeof responseBody.request_uri !== 'string') {
+      throw new RPError({
+        message: 'invalid request_uri value in Pushed Authorization Successful Response',
+        response,
+      });
+    }
+
+    return responseBody;
+  }
+
   /**
    * @name issuer
    * @api public
@@ -1605,7 +1660,7 @@ Object.defineProperty(BaseClient.prototype, 'validateJARM', {
  * @name dpopProof
  * @api private
  */
-function dpopProof(payload, jwk) {
+function dpopProof(payload, jwk, accessToken) {
   if (!isPlainObject(payload)) {
     throw new TypeError('payload must be a plain object');
   }
@@ -1629,9 +1684,15 @@ function dpopProof(payload, jwk) {
     [alg] = key.algorithms('sign');
   }
 
+  let ath;
+  if (accessToken) {
+    ath = base64url.encode(crypto.createHash('sha256').update(accessToken).digest());
+  }
+
   return jose.JWS.sign({
     iat: now(),
     jti: random(),
+    ath,
     ...payload,
   }, jwk, {
     alg,
@@ -1645,7 +1706,7 @@ Object.defineProperty(BaseClient.prototype, 'dpopProof', {
   configurable: true,
   value(...args) {
     process.emitWarning(
-      'The DPoP APIs implements an IETF draft. Breaking draft implementations are included as minor versions of the openid-client library, therefore, the ~ semver operator should be used and close attention be payed to library changelog as well as the drafts themselves.',
+      'The DPoP APIs implements an IETF draft (https://www.ietf.org/archive/id/draft-ietf-oauth-dpop-03.html). Breaking draft implementations are included as minor versions of the openid-client library, therefore, the ~ semver operator should be used and close attention be payed to library changelog as well as the drafts themselves.',
       'DraftWarning',
     );
     Object.defineProperty(BaseClient.prototype, 'dpopProof', {
