@@ -9,9 +9,22 @@ const assert = require('assert')
 
 const kHandler = Symbol('handler')
 
-// Borrowed from https://gist.github.com/dperini/729294
-// eslint-disable-next-line no-control-regex
-const REGEXP_ABSOLUTE_URL = /^(?:(?:https?|ftp):\/\/)(?:\S+(?::\S*)?@)?(?:(?!10(?:\.\d{1,3}){3})(?!127(?:\.\d{1,3}){3})(?!169\.254(?:\.\d{1,3}){2})(?!192\.168(?:\.\d{1,3}){2})(?!172\.(?:1[6-9]|2\d|3[0-1])(?:\.\d{1,3}){2})(?:[1-9]\d?|1\d\d|2[01]\d|22[0-3])(?:\.(?:1?\d{1,2}|2[0-4]\d|25[0-5])){2}(?:\.(?:[1-9]\d?|1\d\d|2[0-4]\d|25[0-4]))|(?:(?:[a-z\x00a1-\xffff0-9]+-?)*[a-z\x00a1-\xffff0-9]+)(?:\.(?:[a-z\x00a1-\xffff0-9]+-?)*[a-z\x00a1-\xffff0-9]+)*(?:\.(?:[a-z\x00a1-\xffff]{2,})))(?::\d{2,5})?(?:\/[^\s]*)?$/ius
+const channels = {}
+
+try {
+  const diagnosticsChannel = require('diagnostics_channel')
+  channels.create = diagnosticsChannel.channel('undici:request:create')
+  channels.bodySent = diagnosticsChannel.channel('undici:request:bodySent')
+  channels.headers = diagnosticsChannel.channel('undici:request:headers')
+  channels.trailers = diagnosticsChannel.channel('undici:request:trailers')
+  channels.error = diagnosticsChannel.channel('undici:request:error')
+} catch {
+  channels.create = { hasSubscribers: false }
+  channels.bodySent = { hasSubscribers: false }
+  channels.headers = { hasSubscribers: false }
+  channels.trailers = { hasSubscribers: false }
+  channels.error = { hasSubscribers: false }
+}
 
 class Request {
   constructor ({
@@ -20,11 +33,14 @@ class Request {
     body,
     headers,
     idempotent,
-    upgrade
+    blocking,
+    upgrade,
+    headersTimeout,
+    bodyTimeout
   }, handler) {
     if (typeof path !== 'string') {
       throw new InvalidArgumentError('path must be a string')
-    } else if (path[0] !== '/' && !REGEXP_ABSOLUTE_URL.test(path)) {
+    } else if (path[0] !== '/' && !(path.startsWith('http://') || path.startsWith('https://'))) {
       throw new InvalidArgumentError('path must be an absolute URL or start with a slash')
     }
 
@@ -36,23 +52,44 @@ class Request {
       throw new InvalidArgumentError('upgrade must be a string')
     }
 
+    if (headersTimeout != null && (!Number.isFinite(headersTimeout) || headersTimeout < 0)) {
+      throw new InvalidArgumentError('invalid headersTimeout')
+    }
+
+    if (bodyTimeout != null && (!Number.isFinite(bodyTimeout) || bodyTimeout < 0)) {
+      throw new InvalidArgumentError('invalid bodyTimeout')
+    }
+
+    this.headersTimeout = headersTimeout
+
+    this.bodyTimeout = bodyTimeout
+
     this.method = method
 
     if (body == null) {
       this.body = null
     } else if (util.isStream(body)) {
       this.body = body
+    } else if (body instanceof DataView) {
+      // TODO: Why is DataView special?
+      this.body = body.buffer.byteLength ? Buffer.from(body.buffer) : null
+    } else if (body instanceof ArrayBuffer || ArrayBuffer.isView(body)) {
+      this.body = body.byteLength ? Buffer.from(body) : null
     } else if (util.isBuffer(body)) {
-      this.body = body.length ? body : null
+      this.body = body.byteLength ? body : null
     } else if (typeof body === 'string') {
       this.body = body.length ? Buffer.from(body) : null
+    } else if (util.isIterable(body) || util.isBlob(body)) {
+      this.body = body
     } else {
-      throw new InvalidArgumentError('body must be a string, a Buffer or a Readable stream')
+      throw new InvalidArgumentError('body must be a string, a Buffer, a Readable stream, an iterable, or an async iterable')
     }
 
+    this.completed = false
+
     this.aborted = false
 
-    this.upgrade = upgrade || method === 'CONNECT' || null
+    this.upgrade = upgrade || null
 
     this.path = path
 
@@ -60,10 +97,14 @@ class Request {
       ? method === 'HEAD' || method === 'GET'
       : idempotent
 
+    this.blocking = blocking == null ? false : blocking
+
     this.host = null
 
     this.contentLength = null
 
+    this.contentType = null
+
     this.headers = ''
 
     if (Array.isArray(headers)) {
@@ -71,81 +112,107 @@ class Request {
         throw new InvalidArgumentError('headers array must be even')
       }
       for (let i = 0; i < headers.length; i += 2) {
-        processHeader(this, headers[i + 0], headers[i + 1])
+        processHeader(this, headers[i], headers[i + 1])
       }
     } else if (headers && typeof headers === 'object') {
-      for (const [key, val] of Object.entries(headers)) {
-        processHeader(this, key, val)
+      const keys = Object.keys(headers)
+      for (let i = 0; i < keys.length; i++) {
+        const key = keys[i]
+        processHeader(this, key, headers[key])
       }
     } else if (headers != null) {
       throw new InvalidArgumentError('headers must be an object or an array')
     }
 
-    if (typeof handler.onConnect !== 'function') {
-      throw new InvalidArgumentError('invalid onConnect method')
+    if (util.isBlob(body) && this.contentType == null) {
+      this.contentType = body.type
+      this.headers += `content-type: ${body.type}\r\n`
     }
 
-    if (typeof handler.onError !== 'function') {
-      throw new InvalidArgumentError('invalid onError method')
-    }
+    util.validateHandler(handler, method, upgrade)
 
-    if (this.upgrade) {
-      if (typeof handler.onUpgrade !== 'function') {
-        throw new InvalidArgumentError('invalid onUpgrade method')
-      }
-    } else {
-      if (typeof handler.onHeaders !== 'function') {
-        throw new InvalidArgumentError('invalid onHeaders method')
-      }
-
-      if (typeof handler.onData !== 'function') {
-        throw new InvalidArgumentError('invalid onData method')
-      }
-
-      if (typeof handler.onComplete !== 'function') {
-        throw new InvalidArgumentError('invalid onComplete method')
-      }
-    }
+    this.servername = util.getServerName(this.host)
 
     this[kHandler] = handler
+
+    if (channels.create.hasSubscribers) {
+      channels.create.publish({ request: this })
+    }
+  }
+
+  onBodySent (chunk) {
+    if (this[kHandler].onBodySent) {
+      try {
+        this[kHandler].onBodySent(chunk)
+      } catch (err) {
+        this.onError(err)
+      }
+    }
+  }
+
+  onRequestSent () {
+    if (channels.bodySent.hasSubscribers) {
+      channels.bodySent.publish({ request: this })
+    }
   }
 
   onConnect (abort) {
     assert(!this.aborted)
+    assert(!this.completed)
+
     return this[kHandler].onConnect(abort)
   }
 
-  onHeaders (statusCode, headers, resume) {
+  onHeaders (statusCode, headers, resume, statusText) {
     assert(!this.aborted)
-    return this[kHandler].onHeaders(statusCode, headers, resume)
+    assert(!this.completed)
+
+    if (channels.headers.hasSubscribers) {
+      channels.headers.publish({ request: this, response: { statusCode, headers, statusText } })
+    }
+
+    return this[kHandler].onHeaders(statusCode, headers, resume, statusText)
   }
 
   onData (chunk) {
     assert(!this.aborted)
-    assert(!this.upgrade)
+    assert(!this.completed)
+
     return this[kHandler].onData(chunk)
   }
 
   onUpgrade (statusCode, headers, socket) {
     assert(!this.aborted)
-    assert(this.upgrade)
+    assert(!this.completed)
+
     return this[kHandler].onUpgrade(statusCode, headers, socket)
   }
 
   onComplete (trailers) {
     assert(!this.aborted)
-    assert(!this.upgrade)
+
+    this.completed = true
+    if (channels.trailers.hasSubscribers) {
+      channels.trailers.publish({ request: this, trailers })
+    }
     return this[kHandler].onComplete(trailers)
   }
 
-  onError (err) {
+  onError (error) {
+    if (channels.error.hasSubscribers) {
+      channels.error.publish({ request: this, error })
+    }
+
     if (this.aborted) {
       return
     }
     this.aborted = true
+    return this[kHandler].onError(error)
+  }
 
-    // Ensure all queued handlers are invoked before calling onError.
-    util.queueMicrotask(() => this[kHandler].onError(err))
+  addHeader (key, value) {
+    processHeader(this, key, value)
+    return this
   }
 }
 
@@ -161,17 +228,24 @@ function processHeader (request, key, val) {
     key.length === 4 &&
     key.toLowerCase() === 'host'
   ) {
+    // Consumed by Client
     request.host = val
-    request.headers += `${key}: ${val}\r\n`
   } else if (
     request.contentLength === null &&
     key.length === 14 &&
     key.toLowerCase() === 'content-length'
   ) {
-    request.contentLength = parseInt(val)
+    request.contentLength = parseInt(val, 10)
     if (!Number.isFinite(request.contentLength)) {
       throw new InvalidArgumentError('invalid content-length header')
     }
+  } else if (
+    request.contentType === null &&
+    key.length === 12 &&
+    key.toLowerCase() === 'content-type'
+  ) {
+    request.contentType = val
+    request.headers += `${key}: ${val}\r\n`
   } else if (
     key.length === 17 &&
     key.toLowerCase() === 'transfer-encoding'
