@@ -11,11 +11,9 @@
 // flowlint ambiguous-object-type:error
 'use strict';
 
-function _createForOfIteratorHelper(o, allowArrayLike) { var it; if (typeof Symbol === "undefined" || o[Symbol.iterator] == null) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e) { throw _e; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = o[Symbol.iterator](); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e2) { didErr = true; err = _e2; }, f: function f() { try { if (!normalCompletion && it["return"] != null) it["return"](); } finally { if (didErr) throw err; } } }; }
+var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
 
-function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
-
-function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }
+var _createForOfIteratorHelper2 = _interopRequireDefault(require("@babel/runtime/helpers/createForOfIteratorHelper"));
 
 var RelayConcreteNode = require('../util/RelayConcreteNode');
 
@@ -37,7 +35,7 @@ var cloneRelayScalarHandleSourceField = require('./cloneRelayScalarHandleSourceF
 
 var getOperation = require('../util/getOperation');
 
-var invariant = require("fbjs/lib/invariant");
+var invariant = require('invariant');
 
 var _require = require('./ClientID'),
     isClientID = _require.isClientID;
@@ -50,6 +48,7 @@ var _require3 = require('./TypeID'),
     generateTypeID = _require3.generateTypeID;
 
 var CONDITION = RelayConcreteNode.CONDITION,
+    CLIENT_COMPONENT = RelayConcreteNode.CLIENT_COMPONENT,
     CLIENT_EXTENSION = RelayConcreteNode.CLIENT_EXTENSION,
     DEFER = RelayConcreteNode.DEFER,
     FLIGHT_FIELD = RelayConcreteNode.FLIGHT_FIELD,
@@ -77,11 +76,11 @@ var ROOT_ID = RelayStoreUtils.ROOT_ID,
  * If all records are present, returns `true`, otherwise `false`.
  */
 
-function check(source, target, selector, handlers, operationLoader, getDataID) {
+function check(source, target, selector, handlers, operationLoader, getDataID, shouldProcessClientComponents) {
   var dataID = selector.dataID,
       node = selector.node,
       variables = selector.variables;
-  var checker = new DataChecker(source, target, variables, handlers, operationLoader, getDataID);
+  var checker = new DataChecker(source, target, variables, handlers, operationLoader, getDataID, shouldProcessClientComponents);
   return checker.check(node, dataID);
 }
 /**
@@ -90,7 +89,7 @@ function check(source, target, selector, handlers, operationLoader, getDataID) {
 
 
 var DataChecker = /*#__PURE__*/function () {
-  function DataChecker(source, target, variables, handlers, operationLoader, getDataID) {
+  function DataChecker(source, target, variables, handlers, operationLoader, getDataID, shouldProcessClientComponents) {
     var mutator = new RelayRecordSourceMutator(source, target);
     this._mostRecentlyInvalidatedAt = null;
     this._handlers = handlers;
@@ -100,6 +99,7 @@ var DataChecker = /*#__PURE__*/function () {
     this._recordWasMissing = false;
     this._source = source;
     this._variables = variables;
+    this._shouldProcessClientComponents = shouldProcessClientComponents;
   }
 
   var _proto = DataChecker.prototype;
@@ -117,7 +117,8 @@ var DataChecker = /*#__PURE__*/function () {
   };
 
   _proto._getVariableValue = function _getVariableValue(name) {
-    !this._variables.hasOwnProperty(name) ? process.env.NODE_ENV !== "production" ? invariant(false, 'RelayAsyncLoader(): Undefined variable `%s`.', name) : invariant(false) : void 0;
+    !this._variables.hasOwnProperty(name) ? process.env.NODE_ENV !== "production" ? invariant(false, 'RelayAsyncLoader(): Undefined variable `%s`.', name) : invariant(false) : void 0; // $FlowFixMe[cannot-write]
+
     return this._variables[name];
   };
 
@@ -147,7 +148,7 @@ var DataChecker = /*#__PURE__*/function () {
         args = _this$_getDataForHand.args,
         record = _this$_getDataForHand.record;
 
-    var _iterator = _createForOfIteratorHelper(this._handlers),
+    var _iterator = (0, _createForOfIteratorHelper2["default"])(this._handlers),
         _step;
 
     try {
@@ -176,7 +177,7 @@ var DataChecker = /*#__PURE__*/function () {
         args = _this$_getDataForHand2.args,
         record = _this$_getDataForHand2.record;
 
-    var _iterator2 = _createForOfIteratorHelper(this._handlers),
+    var _iterator2 = (0, _createForOfIteratorHelper2["default"])(this._handlers),
         _step2;
 
     try {
@@ -207,7 +208,7 @@ var DataChecker = /*#__PURE__*/function () {
         args = _this$_getDataForHand3.args,
         record = _this$_getDataForHand3.record;
 
-    var _iterator3 = _createForOfIteratorHelper(this._handlers),
+    var _iterator3 = (0, _createForOfIteratorHelper2["default"])(this._handlers),
         _step3;
 
     try {
@@ -367,7 +368,7 @@ var DataChecker = /*#__PURE__*/function () {
         // $FlowFixMe[incompatible-type]
 
         case FRAGMENT_SPREAD:
-          !false ? process.env.NODE_ENV !== "production" ? invariant(false, 'RelayAsyncLoader(): Unexpected ast kind `%s`.', selection.kind) : invariant(false) : void 0; // $FlowExpectedError[unreachable-code] - we need the break; for OSS linter
+          _this2._traverseSelections(selection.fragment.selections, dataID);
 
           break;
 
@@ -410,6 +411,15 @@ var DataChecker = /*#__PURE__*/function () {
 
           break;
 
+        case CLIENT_COMPONENT:
+          if (_this2._shouldProcessClientComponents === false) {
+            break;
+          }
+
+          _this2._traverseSelections(selection.fragment.selections, dataID);
+
+          break;
+
         default:
           selection;
           !false ? process.env.NODE_ENV !== "production" ? invariant(false, 'RelayAsyncLoader(): Unexpected ast kind `%s`.', selection.kind) : invariant(false) : void 0;
@@ -522,28 +532,28 @@ var DataChecker = /*#__PURE__*/function () {
 
     var tree = this._mutator.getValue(linkedID, RelayStoreReactFlightUtils.REACT_FLIGHT_TREE_STORAGE_KEY);
 
-    var reachableQueries = this._mutator.getValue(linkedID, RelayStoreReactFlightUtils.REACT_FLIGHT_QUERIES_STORAGE_KEY);
+    var reachableExecutableDefinitions = this._mutator.getValue(linkedID, RelayStoreReactFlightUtils.REACT_FLIGHT_EXECUTABLE_DEFINITIONS_STORAGE_KEY);
 
-    if (tree == null || !Array.isArray(reachableQueries)) {
+    if (tree == null || !Array.isArray(reachableExecutableDefinitions)) {
       this._handleMissing();
 
       return;
     }
 
     var operationLoader = this._operationLoader;
-    !(operationLoader !== null) ? process.env.NODE_ENV !== "production" ? invariant(false, 'DataChecker: Expected an operationLoader to be configured when using ' + 'React Flight.') : invariant(false) : void 0; // In Flight, the variables that are in scope for reachable queries aren't
-    // the same as what's in scope for the outer query.
+    !(operationLoader !== null) ? process.env.NODE_ENV !== "production" ? invariant(false, 'DataChecker: Expected an operationLoader to be configured when using ' + 'React Flight.') : invariant(false) : void 0; // In Flight, the variables that are in scope for reachable executable
+    // definitions aren't the same as what's in scope for the outer query.
 
     var prevVariables = this._variables; // $FlowFixMe[incompatible-cast]
 
-    var _iterator4 = _createForOfIteratorHelper(reachableQueries),
+    var _iterator4 = (0, _createForOfIteratorHelper2["default"])(reachableExecutableDefinitions),
         _step4;
 
     try {
       for (_iterator4.s(); !(_step4 = _iterator4.n()).done;) {
-        var query = _step4.value;
-        this._variables = query.variables;
-        var normalizationRootNode = operationLoader.get(query.module);
+        var definition = _step4.value;
+        this._variables = definition.variables;
+        var normalizationRootNode = operationLoader.get(definition.module);
 
         if (normalizationRootNode != null) {
           var operation = getOperation(normalizationRootNode);
