@@ -10,11 +10,15 @@
 // flowlint ambiguous-object-type:error
 'use strict';
 
+var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
+
+var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));
+
 var RelayFeatureFlags = require('../util/RelayFeatureFlags');
 
 var RelayModernRecord = require('./RelayModernRecord');
 
-var invariant = require("fbjs/lib/invariant");
+var invariant = require('invariant');
 
 var _require = require('../util/RelayConcreteNode'),
     CLIENT_EXTENSION = _require.CLIENT_EXTENSION,
@@ -27,6 +31,7 @@ var _require = require('../util/RelayConcreteNode'),
     LINKED_FIELD = _require.LINKED_FIELD,
     MODULE_IMPORT = _require.MODULE_IMPORT,
     REQUIRED_FIELD = _require.REQUIRED_FIELD,
+    RELAY_RESOLVER = _require.RELAY_RESOLVER,
     SCALAR_FIELD = _require.SCALAR_FIELD,
     STREAM = _require.STREAM;
 
@@ -45,8 +50,11 @@ var _require3 = require('./RelayStoreUtils'),
     getStorageKey = _require3.getStorageKey,
     getModuleComponentKey = _require3.getModuleComponentKey;
 
-var _require4 = require('./TypeID'),
-    generateTypeID = _require4.generateTypeID;
+var _require4 = require('./ResolverFragments'),
+    withResolverContext = _require4.withResolverContext;
+
+var _require5 = require('./TypeID'),
+    generateTypeID = _require5.generateTypeID;
 
 function read(recordSource, selector) {
   var reader = new RelayReader(recordSource, selector);
@@ -64,7 +72,7 @@ var RelayReader = /*#__PURE__*/function () {
     this._missingRequiredFields = null;
     this._owner = selector.owner;
     this._recordSource = recordSource;
-    this._seenRecords = {};
+    this._seenRecords = new Set();
     this._selector = selector;
     this._variables = selector.variables;
   }
@@ -138,7 +146,7 @@ var RelayReader = /*#__PURE__*/function () {
   _proto._traverse = function _traverse(node, dataID, prevData) {
     var record = this._recordSource.get(dataID);
 
-    this._seenRecords[dataID] = record;
+    this._seenRecords.add(dataID);
 
     if (record == null) {
       if (record === undefined) {
@@ -156,7 +164,8 @@ var RelayReader = /*#__PURE__*/function () {
   };
 
   _proto._getVariableValue = function _getVariableValue(name) {
-    !this._variables.hasOwnProperty(name) ? process.env.NODE_ENV !== "production" ? invariant(false, 'RelayReader(): Undefined variable `%s`.', name) : invariant(false) : void 0;
+    !this._variables.hasOwnProperty(name) ? process.env.NODE_ENV !== "production" ? invariant(false, 'RelayReader(): Undefined variable `%s`.', name) : invariant(false) : void 0; // $FlowFixMe[cannot-write]
+
     return this._variables[name];
   };
 
@@ -309,6 +318,17 @@ var RelayReader = /*#__PURE__*/function () {
             break;
           }
 
+        case RELAY_RESOLVER:
+          {
+            if (!RelayFeatureFlags.ENABLE_RELAY_RESOLVERS) {
+              throw new Error('Relay Resolver fields are not yet supported.');
+            }
+
+            this._readResolverField(selection, record, data);
+
+            break;
+          }
+
         case FRAGMENT_SPREAD:
           this._createFragmentPointer(selection, record, data);
 
@@ -320,7 +340,7 @@ var RelayReader = /*#__PURE__*/function () {
           break;
 
         case INLINE_DATA_FRAGMENT_SPREAD:
-          this._createInlineDataFragmentPointer(selection, record, data);
+          this._createInlineDataOrResolverFragmentPointer(selection, record, data);
 
           break;
 
@@ -387,6 +407,40 @@ var RelayReader = /*#__PURE__*/function () {
     }
   };
 
+  _proto._readResolverField = function _readResolverField(selection, record, data) {
+    var _this = this;
+
+    var name = selection.name,
+        alias = selection.alias,
+        resolverModule = selection.resolverModule,
+        fragment = selection.fragment;
+    var key = {
+      __id: RelayModernRecord.getDataID(record),
+      __fragmentOwner: this._owner,
+      __fragments: (0, _defineProperty2["default"])({}, fragment.name, {})
+    };
+    var resolverContext = {
+      getDataForResolverFragment: function getDataForResolverFragment(singularReaderSelector) {
+        var _resolverFragmentData;
+
+        var resolverFragmentData = {};
+
+        _this._createInlineDataOrResolverFragmentPointer(singularReaderSelector.node, record, resolverFragmentData);
+
+        var answer = (_resolverFragmentData = resolverFragmentData[FRAGMENTS_KEY]) === null || _resolverFragmentData === void 0 ? void 0 : _resolverFragmentData[fragment.name];
+        !(typeof answer === 'object' && answer !== null) ? process.env.NODE_ENV !== "production" ? invariant(false, "Expected reader data to contain a __fragments property with a property for the fragment named ".concat(fragment.name, ", but it is missing.")) : invariant(false) : void 0;
+        return answer;
+      }
+    };
+    var resolverResult = withResolverContext(resolverContext, function () {
+      return (// $FlowFixMe[prop-missing] - resolver module's type signature is a lie
+        resolverModule(key)
+      );
+    });
+    data[alias !== null && alias !== void 0 ? alias : name] = resolverResult;
+    return resolverResult;
+  };
+
   _proto._readFlightField = function _readFlightField(field, record, data) {
     var _field$alias;
 
@@ -406,7 +460,7 @@ var RelayReader = /*#__PURE__*/function () {
 
     var reactFlightClientResponseRecord = this._recordSource.get(reactFlightClientResponseRecordID);
 
-    this._seenRecords[reactFlightClientResponseRecordID] = reactFlightClientResponseRecord;
+    this._seenRecords.add(reactFlightClientResponseRecordID);
 
     if (reactFlightClientResponseRecord == null) {
       data[applicationName] = reactFlightClientResponseRecord;
@@ -465,7 +519,7 @@ var RelayReader = /*#__PURE__*/function () {
   };
 
   _proto._readPluralLink = function _readPluralLink(field, record, data) {
-    var _this = this;
+    var _this2 = this;
 
     var _field$alias4;
 
@@ -489,7 +543,7 @@ var RelayReader = /*#__PURE__*/function () {
     linkedIDs.forEach(function (linkedID, nextIndex) {
       if (linkedID == null) {
         if (linkedID === undefined) {
-          _this._isMissingData = true;
+          _this2._isMissingData = true;
         } // $FlowFixMe[cannot-write]
 
 
@@ -501,7 +555,7 @@ var RelayReader = /*#__PURE__*/function () {
       !(prevItem == null || typeof prevItem === 'object') ? process.env.NODE_ENV !== "production" ? invariant(false, 'RelayReader(): Expected data for field `%s` on record `%s` ' + 'to be an object, got `%s`.', applicationName, RelayModernRecord.getDataID(record), prevItem) : invariant(false) : void 0; // $FlowFixMe[cannot-write]
       // $FlowFixMe[incompatible-variance]
 
-      linkedArray[nextIndex] = _this._traverse(field, linkedID, prevItem);
+      linkedArray[nextIndex] = _this2._traverse(field, linkedID, prevItem);
     });
     data[applicationName] = linkedArray;
     return linkedArray;
@@ -563,7 +617,7 @@ var RelayReader = /*#__PURE__*/function () {
     }
   };
 
-  _proto._createInlineDataFragmentPointer = function _createInlineDataFragmentPointer(inlineDataFragmentSpread, record, data) {
+  _proto._createInlineDataOrResolverFragmentPointer = function _createInlineDataOrResolverFragmentPointer(fragmentSpreadOrFragment, record, data) {
     var fragmentPointers = data[FRAGMENTS_KEY];
 
     if (fragmentPointers == null) {
@@ -578,10 +632,10 @@ var RelayReader = /*#__PURE__*/function () {
 
     var inlineData = {};
 
-    this._traverseSelections(inlineDataFragmentSpread.selections, record, inlineData); // $FlowFixMe[cannot-write] - writing into read-only field
+    this._traverseSelections(fragmentSpreadOrFragment.selections, record, inlineData); // $FlowFixMe[cannot-write] - writing into read-only field
 
 
-    fragmentPointers[inlineDataFragmentSpread.name] = inlineData;
+    fragmentPointers[fragmentSpreadOrFragment.name] = inlineData;
   };
 
   return RelayReader;
