@@ -3,5 +3,8 @@ export * from './FocusTrap/FocusTrap';
 export * from './GenerateId/GenerateId';
 export * from './htmlConstants';
 export * from './typeUtils';
-export * from './ouia';
+export * from './OUIA/ouia';
 export * from './util';
+export * from './Popper/Popper';
+export * from './useIsomorphicLayout';
+export * from './KeyboardHandler';
